@@ -34,8 +34,8 @@ import org.apache.flink.runtime.checkpoint.channel.InputChannelInfo;
 import org.apache.flink.runtime.checkpoint.channel.ResultSubpartitionInfo;
 import org.apache.flink.runtime.clusterframework.types.ResourceID;
 import org.apache.flink.runtime.deployment.InputGateDeploymentDescriptor;
+import org.apache.flink.runtime.deployment.SubpartitionIndexRange;
 import org.apache.flink.runtime.event.TaskEvent;
-import org.apache.flink.runtime.executiongraph.IndexRange;
 import org.apache.flink.runtime.io.network.ConnectionID;
 import org.apache.flink.runtime.io.network.LocalConnectionManager;
 import org.apache.flink.runtime.io.network.api.CheckpointBarrier;
@@ -44,7 +44,6 @@ import org.apache.flink.runtime.io.network.buffer.BufferDecompressor;
 import org.apache.flink.runtime.io.network.buffer.BufferPool;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionType;
-import org.apache.flink.runtime.io.network.partition.ResultSubpartitionIndexSet;
 import org.apache.flink.runtime.io.network.partition.consumer.BufferOrEvent;
 import org.apache.flink.runtime.io.network.partition.consumer.IndexedInputGate;
 import org.apache.flink.runtime.io.network.partition.consumer.InputChannel;
@@ -210,15 +209,13 @@ public class RemoteShuffleInputGate extends IndexedInputGate {
   /** Accommodation for the incompleteness of Flink pluggable shuffle service. */
   private class FakedRemoteInputChannel extends RemoteInputChannel {
     FakedRemoteInputChannel(int channelIndex) {
-      // Flink 1.19.0
-      // [FLINK-25055][network] Support listen and notify mechanism for partition request
-      // [FLINK-33743][runtime] Support consuming multiple subpartitions on a single channel
       super(
           new SingleInputGate(
               inputGateDelegation.getTaskName(),
               inputGateDelegation.getGateIndex(),
               new IntermediateDataSetID(),
               ResultPartitionType.BLOCKING,
+              new SubpartitionIndexRange(0, 0),
               1,
               (a, b, c) -> {},
               () -> null,
@@ -229,7 +226,7 @@ public class RemoteShuffleInputGate extends IndexedInputGate {
               null),
           channelIndex,
           new ResultPartitionID(),
-          new ResultSubpartitionIndexSet(new IndexRange(0, 0)),
+          0,
           new ConnectionID(
               new TaskManagerLocation(ResourceID.generate(), InetAddress.getLoopbackAddress(), 1),
               0),
@@ -237,7 +234,6 @@ public class RemoteShuffleInputGate extends IndexedInputGate {
           0,
           0,
           0,
-          0,
           new SimpleCounter(),
           new SimpleCounter(),
           new FakedChannelStateWriter());
@@ -271,14 +267,6 @@ public class RemoteShuffleInputGate extends IndexedInputGate {
     public void addOutputData(
         long cpId, ResultSubpartitionInfo info, int startSeqNum, Buffer... data) {}
 
-    @Override
-    public void addOutputDataFuture(
-        long l,
-        ResultSubpartitionInfo resultSubpartitionInfo,
-        int i,
-        CompletableFuture<List<Buffer>> completableFuture)
-        throws IllegalArgumentException {}
-
     @Override
     public void finishInput(long checkpointId) {}
 
