@@ -292,7 +292,7 @@ public class SortBasedPusher extends MemoryConsumer {
     long threshold = pushSortMemoryThreshold;
     if (getUsed() > threshold
         && pageCursor + required > currentPage.getBaseOffset() + currentPage.size()) {
-      logger.info(
+      logger.debug(
           "Memory used {} exceeds threshold {}, need to trigger push. currentPage size: {}",
           Utils.bytesToString(getUsed()),
           Utils.bytesToString(pushSortMemoryThreshold),
@@ -501,13 +501,15 @@ public class SortBasedPusher extends MemoryConsumer {
     return this.pushSortMemoryThreshold;
   }
 
-  public void close() throws IOException {
+  public void close(boolean throwTaskKilledOnInterruption) throws IOException {
     cleanupResources();
     try {
       dataPusher.waitOnTermination();
-      sendBufferPool.returnPushTaskQueue(dataPusher.getIdleQueue());
+      sendBufferPool.returnPushTaskQueue(dataPusher.getAndResetIdleQueue());
     } catch (InterruptedException e) {
-      TaskInterruptedHelper.throwTaskKillException();
+      if (throwTaskKilledOnInterruption) {
+        TaskInterruptedHelper.throwTaskKillException();
+      }
     }
   }
 
