@@ -21,15 +21,18 @@ import java.io.File
 import java.util
 
 import scala.collection.JavaConverters._
+import scala.collection.mutable
 import scala.util.Random
 
 import org.apache.hadoop.shaded.org.apache.commons.lang3.RandomStringUtils
 
 import org.apache.celeborn.CelebornFunSuite
 import org.apache.celeborn.common.identity.UserIdentifier
-import org.apache.celeborn.common.meta.{ApplicationMeta, DeviceInfo, DiskFileInfo, DiskInfo, MapFileMeta, ReduceFileMeta, WorkerEventInfo, WorkerInfo, WorkerStatus}
+import org.apache.celeborn.common.meta._
 import org.apache.celeborn.common.protocol.{PartitionLocation, PbPackedWorkerResource, PbWorkerResource, StorageInfo}
-import org.apache.celeborn.common.protocol.message.ControlMessages.WorkerResource
+import org.apache.celeborn.common.protocol.PartitionLocation.Mode
+import org.apache.celeborn.common.protocol.message.{ControlMessages, StatusCode}
+import org.apache.celeborn.common.protocol.message.ControlMessages.{GetReducerFileGroupResponse, WorkerResource}
 import org.apache.celeborn.common.quota.ResourceConsumption
 import org.apache.celeborn.common.util.PbSerDeUtils.{fromPbPackedPartitionLocationsPair, toPbPackedPartitionLocationsPair}
 
@@ -466,4 +469,96 @@ class PbSerDeUtilsTest extends CelebornFunSuite {
     testSerializationPerformance(100)
   }
 
+  test("GetReduceFileGroup with primary and replica locations") {
+    val shuffleMap: util.Map[Integer, util.Set[PartitionLocation]] =
+      JavaUtils.newConcurrentHashMap()
+    val locationSet = new util.LinkedHashSet[PartitionLocation]()
+    val uniqueIds = mutable.Set("0-0", "1-0", "2-0", "3-0", "4-0")
+    locationSet.add(new PartitionLocation(0, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(1, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(2, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(3, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(4, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    shuffleMap.put(1, locationSet)
+    val attempts = Array.fill(10)(10)
+    val succeedPartitions = Array.fill(10)(10).map(java.lang.Integer.valueOf).toSet.asJava
+
+    val GetReducerFileGroupResponseMsg = GetReducerFileGroupResponse(
+      StatusCode.SUCCESS,
+      shuffleMap,
+      attempts,
+      succeedPartitions)
+
+    val transportGetReducerFileGroup =
+      ControlMessages.toTransportMessage(GetReducerFileGroupResponseMsg)
+    val fromTransportGetReducerFileGroup: GetReducerFileGroupResponse =
+      ControlMessages.fromTransportMessage(
+        transportGetReducerFileGroup).asInstanceOf[GetReducerFileGroupResponse]
+
+    val locations = fromTransportGetReducerFileGroup.fileGroup.get(1)
+    locations.asScala.foreach(p => uniqueIds.remove(p.getUniqueId))
+    assert(uniqueIds.isEmpty)
+  }
+
+  test("GetReduceFileGroup with primary location only") {
+    val shuffleMap: util.Map[Integer, util.Set[PartitionLocation]] =
+      JavaUtils.newConcurrentHashMap()
+    val locationSet = new util.LinkedHashSet[PartitionLocation]()
+    val uniqueIds = mutable.Set("0-0", "1-0", "2-0", "3-0", "4-0")
+    locationSet.add(new PartitionLocation(0, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(1, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(2, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(3, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    locationSet.add(new PartitionLocation(4, 0, "h", 1, 1, 1, 1, Mode.PRIMARY))
+    shuffleMap.put(1, locationSet)
+    val attempts = Array.fill(10)(10)
+    val succeedPartitions = Array.fill(10)(10).map(java.lang.Integer.valueOf).toSet.asJava
+
+    val GetReducerFileGroupResponseMsg = GetReducerFileGroupResponse(
+      StatusCode.SUCCESS,
+      shuffleMap,
+      attempts,
+      succeedPartitions)
+
+    val transportGetReducerFileGroup =
+      ControlMessages.toTransportMessage(GetReducerFileGroupResponseMsg)
+    val fromTransportGetReducerFileGroup: GetReducerFileGroupResponse =
+      ControlMessages.fromTransportMessage(
+        transportGetReducerFileGroup).asInstanceOf[GetReducerFileGroupResponse]
+
+    val locations = fromTransportGetReducerFileGroup.fileGroup.get(1)
+    locations.asScala.foreach(p => uniqueIds.remove(p.getUniqueId))
+    assert(uniqueIds.isEmpty)
+  }
+
+  test("GetReduceFileGroup with replica location only") {
+    val shuffleMap: util.Map[Integer, util.Set[PartitionLocation]] =
+      JavaUtils.newConcurrentHashMap()
+    val locationSet = new util.LinkedHashSet[PartitionLocation]()
+    val uniqueIds = mutable.Set("0-0", "1-0", "2-0", "3-0", "4-0")
+    locationSet.add(new PartitionLocation(0, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(1, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(2, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(3, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    locationSet.add(new PartitionLocation(4, 0, "h", 1, 1, 1, 1, Mode.REPLICA))
+    shuffleMap.put(1, locationSet)
+    val attempts = Array.fill(10)(10)
+    val succeedPartitions = Array.fill(10)(10).map(java.lang.Integer.valueOf).toSet.asJava
+
+    val GetReducerFileGroupResponseMsg = GetReducerFileGroupResponse(
+      StatusCode.SUCCESS,
+      shuffleMap,
+      attempts,
+      succeedPartitions)
+
+    val transportGetReducerFileGroup =
+      ControlMessages.toTransportMessage(GetReducerFileGroupResponseMsg)
+    val fromTransportGetReducerFileGroup: GetReducerFileGroupResponse =
+      ControlMessages.fromTransportMessage(
+        transportGetReducerFileGroup).asInstanceOf[GetReducerFileGroupResponse]
+
+    val locations = fromTransportGetReducerFileGroup.fileGroup.get(1)
+    locations.asScala.foreach(p => uniqueIds.remove(p.getUniqueId))
+    assert(uniqueIds.isEmpty)
+  }
 }
