@@ -34,8 +34,10 @@ import org.junit.Test;
 import org.apache.celeborn.common.CelebornConf;
 import org.apache.celeborn.common.client.MasterClient;
 import org.apache.celeborn.common.identity.UserIdentifier;
+import org.apache.celeborn.common.meta.ApplicationMeta;
 import org.apache.celeborn.common.meta.DiskInfo;
 import org.apache.celeborn.common.meta.WorkerInfo;
+import org.apache.celeborn.common.meta.WorkerStatus;
 import org.apache.celeborn.common.quota.ResourceConsumption;
 import org.apache.celeborn.common.rpc.RpcEndpointAddress;
 import org.apache.celeborn.common.rpc.RpcEndpointRef;
@@ -57,6 +59,8 @@ public class DefaultMetaSystemSuiteJ {
   private static final int PUSHPORT1 = 1112;
   private static final int FETCHPORT1 = 1113;
   private static final int REPLICATEPORT1 = 1114;
+  private static final int INTERNALPORT1 = 1115;
+  private static final String NETWORK_LOCATION1 = "networkLocation1";
   private static final Map<String, DiskInfo> disks1 = new HashMap<>();
   private static final Map<UserIdentifier, ResourceConsumption> userResourceConsumption1 =
       new HashMap<>();
@@ -66,6 +70,8 @@ public class DefaultMetaSystemSuiteJ {
   private static final int PUSHPORT2 = 2112;
   private static final int FETCHPORT2 = 2113;
   private static final int REPLICATEPORT2 = 2114;
+  private static final int INTERNALPORT2 = 2115;
+  private static final String NETWORK_LOCATION2 = "networkLocation2";
   private static final Map<String, DiskInfo> disks2 = new HashMap<>();
   private static final Map<UserIdentifier, ResourceConsumption> userResourceConsumption2 =
       new HashMap<>();
@@ -75,10 +81,14 @@ public class DefaultMetaSystemSuiteJ {
   private static final int PUSHPORT3 = 3112;
   private static final int FETCHPORT3 = 3113;
   private static final int REPLICATEPORT3 = 3114;
+  private static final int INTERNALPORT3 = 3115;
+  private static final String NETWORK_LOCATION3 = "networkLocation3";
   private static final Map<String, DiskInfo> disks3 = new HashMap<>();
   private static final Map<UserIdentifier, ResourceConsumption> userResourceConsumption3 =
       new HashMap<>();
 
+  private static final WorkerStatus workerStatus = WorkerStatus.normalWorkerStatus();
+
   @Before
   public void setUp() {
     when(mockRpcEnv.setupEndpointRef(any(), any())).thenReturn(dummyRef);
@@ -119,6 +129,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -128,6 +140,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -137,6 +151,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -153,6 +169,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT1,
             FETCHPORT1,
             REPLICATEPORT1,
+            INTERNALPORT1,
             disks1,
             userResourceConsumption1);
     WorkerInfo workerInfo2 =
@@ -162,6 +179,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT2,
             FETCHPORT2,
             REPLICATEPORT2,
+            INTERNALPORT2,
             disks2,
             userResourceConsumption2);
 
@@ -171,6 +189,8 @@ public class DefaultMetaSystemSuiteJ {
         workerInfo1.pushPort(),
         workerInfo1.fetchPort(),
         workerInfo1.replicatePort(),
+        workerInfo1.internalPort(),
+        workerInfo1.networkLocation(),
         workerInfo1.diskInfos(),
         workerInfo1.userResourceConsumption(),
         getNewReqeustId());
@@ -180,6 +200,8 @@ public class DefaultMetaSystemSuiteJ {
         workerInfo2.pushPort(),
         workerInfo2.fetchPort(),
         workerInfo2.replicatePort(),
+        workerInfo2.internalPort(),
+        workerInfo2.networkLocation(),
         workerInfo2.diskInfos(),
         workerInfo2.userResourceConsumption(),
         getNewReqeustId());
@@ -201,6 +223,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -210,6 +234,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -219,6 +245,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -240,6 +268,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -249,6 +279,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -258,6 +290,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -269,6 +303,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT1,
             FETCHPORT1,
             REPLICATEPORT1,
+            INTERNALPORT1,
             disks1,
             userResourceConsumption1);
     WorkerInfo workerInfo2 =
@@ -278,6 +313,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT2,
             FETCHPORT2,
             REPLICATEPORT2,
+            INTERNALPORT2,
             disks2,
             userResourceConsumption2);
     WorkerInfo workerInfo3 =
@@ -287,6 +323,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT3,
             FETCHPORT3,
             REPLICATEPORT3,
+            INTERNALPORT3,
             disks3,
             userResourceConsumption3);
 
@@ -311,6 +348,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -320,6 +359,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -329,6 +370,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -371,6 +414,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -380,6 +425,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -389,6 +436,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -400,6 +449,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT1,
             FETCHPORT1,
             REPLICATEPORT1,
+            INTERNALPORT1,
             disks1,
             userResourceConsumption1);
     WorkerInfo workerInfo2 =
@@ -409,6 +459,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT2,
             FETCHPORT2,
             REPLICATEPORT2,
+            INTERNALPORT2,
             disks2,
             userResourceConsumption2);
 
@@ -418,13 +469,15 @@ public class DefaultMetaSystemSuiteJ {
     workersToAllocate.put(workerInfo1.toUniqueId(), allocation);
     workersToAllocate.put(workerInfo2.toUniqueId(), allocation);
 
+    statusSystem.handleApplicationMeta(new ApplicationMeta(APPID1, "testSecret"));
     statusSystem.handleRequestSlots(SHUFFLEKEY1, HOSTNAME1, workersToAllocate, getNewReqeustId());
 
     assertEquals(1, statusSystem.registeredShuffle.size());
-
+    assertEquals(1, statusSystem.applicationMetas.size());
     statusSystem.handleAppLost(APPID1, getNewReqeustId());
 
     assertTrue(statusSystem.registeredShuffle.isEmpty());
+    assertTrue(statusSystem.applicationMetas.isEmpty());
   }
 
   @Test
@@ -435,6 +488,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -444,6 +499,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -453,6 +510,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -464,6 +523,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT1,
             FETCHPORT1,
             REPLICATEPORT1,
+            INTERNALPORT1,
             disks1,
             userResourceConsumption1);
     WorkerInfo workerInfo2 =
@@ -473,6 +533,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT2,
             FETCHPORT2,
             REPLICATEPORT2,
+            INTERNALPORT2,
             disks2,
             userResourceConsumption2);
 
@@ -512,6 +573,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         new HashMap<>(),
         userResourceConsumption1,
         getNewReqeustId());
@@ -521,6 +584,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         new HashMap<>(),
         userResourceConsumption2,
         getNewReqeustId());
@@ -530,6 +595,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         new HashMap<>(),
         userResourceConsumption3,
         getNewReqeustId());
@@ -545,6 +612,7 @@ public class DefaultMetaSystemSuiteJ {
         new HashMap<>(),
         1,
         false,
+        workerStatus,
         getNewReqeustId());
 
     assertEquals(statusSystem.excludedWorkers.size(), 1);
@@ -560,6 +628,7 @@ public class DefaultMetaSystemSuiteJ {
         new HashMap<>(),
         1,
         false,
+        workerStatus,
         getNewReqeustId());
 
     assertEquals(statusSystem.excludedWorkers.size(), 2);
@@ -575,6 +644,7 @@ public class DefaultMetaSystemSuiteJ {
         new HashMap<>(),
         1,
         false,
+        workerStatus,
         getNewReqeustId());
 
     assertEquals(statusSystem.excludedWorkers.size(), 2);
@@ -590,6 +660,7 @@ public class DefaultMetaSystemSuiteJ {
         new HashMap<>(),
         1,
         true,
+        workerStatus,
         getNewReqeustId());
 
     assertEquals(statusSystem.excludedWorkers.size(), 3);
@@ -603,6 +674,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT1,
         FETCHPORT1,
         REPLICATEPORT1,
+        INTERNALPORT1,
+        NETWORK_LOCATION1,
         disks1,
         userResourceConsumption1,
         getNewReqeustId());
@@ -612,6 +685,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT2,
         FETCHPORT2,
         REPLICATEPORT2,
+        INTERNALPORT2,
+        NETWORK_LOCATION2,
         disks2,
         userResourceConsumption2,
         getNewReqeustId());
@@ -621,6 +696,8 @@ public class DefaultMetaSystemSuiteJ {
         PUSHPORT3,
         FETCHPORT3,
         REPLICATEPORT3,
+        INTERNALPORT3,
+        NETWORK_LOCATION3,
         disks3,
         userResourceConsumption3,
         getNewReqeustId());
@@ -633,6 +710,7 @@ public class DefaultMetaSystemSuiteJ {
             PUSHPORT1,
             FETCHPORT1,
             REPLICATEPORT1,
+            INTERNALPORT1,
             disks1,
             userResourceConsumption1));
 
@@ -673,4 +751,17 @@ public class DefaultMetaSystemSuiteJ {
     statusSystem.handleUpdatePartitionSize();
     Assert.assertEquals(statusSystem.estimatedPartitionSize, conf.minPartitionSizeToEstimate());
   }
+
+  @Test
+  public void testHandleApplicationMeta() {
+    String appSecret = "testSecret";
+    statusSystem.handleApplicationMeta(new ApplicationMeta(APPID1, appSecret));
+    assertEquals(appSecret, statusSystem.applicationMetas.get(APPID1).secret());
+
+    String appId2 = "app02";
+    String appSecret2 = "testSecret2";
+    statusSystem.handleApplicationMeta(new ApplicationMeta(appId2, appSecret2));
+    assertEquals(appSecret2, statusSystem.applicationMetas.get(appId2).secret());
+    assertEquals(2, statusSystem.applicationMetas.size());
+  }
 }
