@@ -197,9 +197,9 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
             3,
             Collections.singletonMap("appId3", new ResourceConsumption(2000, 2, 2000, 2, null))));
 
-    WorkerInfo info1 = new WorkerInfo("host1", 1, 2, 3, 10, disks1, userResourceConsumption1);
-    WorkerInfo info2 = new WorkerInfo("host2", 4, 5, 6, 11, disks2, userResourceConsumption2);
-    WorkerInfo info3 = new WorkerInfo("host3", 7, 8, 9, 12, disks3, userResourceConsumption3);
+    WorkerInfo info1 = new WorkerInfo("host1", 1, 2, 3, 10, 13, disks1, userResourceConsumption1);
+    WorkerInfo info2 = new WorkerInfo("host2", 4, 5, 6, 11, 15, disks2, userResourceConsumption2);
+    WorkerInfo info3 = new WorkerInfo("host3", 7, 8, 9, 12, 17, disks3, userResourceConsumption3);
 
     String host1 = "host1";
     String host2 = "host2";
@@ -232,9 +232,9 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
     AppDiskUsageSnapShot originCurrentSnapshot =
         masterStatusSystem.appDiskUsageMetric.currentSnapShot().get();
 
-    masterStatusSystem.workers.add(new WorkerInfo(host1, 9095, 9094, 9093, 9092));
-    masterStatusSystem.workers.add(new WorkerInfo(host2, 9095, 9094, 9093, 9092));
-    masterStatusSystem.workers.add(new WorkerInfo(host3, 9095, 9094, 9093, 9092));
+    masterStatusSystem.workers.add(new WorkerInfo(host1, 9095, 9094, 9093, 9092, 9091));
+    masterStatusSystem.workers.add(new WorkerInfo(host2, 9095, 9094, 9093, 9092, 9091));
+    masterStatusSystem.workers.add(new WorkerInfo(host3, 9095, 9094, 9093, 9092, 9091));
 
     masterStatusSystem.writeMetaInfoToFile(tmpFile);
 
@@ -333,6 +333,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
             .setHost(Utils.localHostName(conf1))
             .setRatisPort(9200)
             .setRpcPort(9201)
+            .setInternalRpcPort(9203)
+            .setSslEnabled(false)
             .setNodeId(UUID.randomUUID().toString())
             .build();
     MasterNode masterNode2 =
@@ -340,6 +342,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
             .setHost(Utils.localHostName(conf2))
             .setRatisPort(9204)
             .setRpcPort(9205)
+            .setInternalRpcPort(9206)
+            .setSslEnabled(false)
             .setNodeId(UUID.randomUUID().toString())
             .build();
     MasterNode masterNode3 =
@@ -347,6 +351,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
             .setHost(Utils.localHostName(conf3))
             .setRatisPort(9207)
             .setRpcPort(9208)
+            .setInternalRpcPort(9209)
+            .setSslEnabled(false)
             .setNodeId(UUID.randomUUID().toString())
             .build();
     HARaftServer raftServer1 =
@@ -415,6 +421,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
           2000 + i,
           3000 + i,
           4000 + i,
+          5000 + i,
+          "networkLocation1",
           disks1,
           userResourceConsumption1,
           getNewReqeustId());
@@ -448,6 +456,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
           2100 + i,
           3100 + i,
           4100 + i,
+          5100 + i,
+          "networkLocation1",
           disks1,
           userResourceConsumption1,
           getNewReqeustId());
@@ -488,6 +498,8 @@ public class MasterStateMachineSuiteJ extends RatisBaseSuiteJ {
           2180 + i,
           3180 + i,
           4180 + i,
+          5180 + i,
+          "networkLocation1",
           disks1,
           userResourceConsumption1,
           getNewReqeustId());
