@@ -17,14 +17,17 @@
 
 package org.apache.celeborn.server.common.service.config;
 
-import java.io.IOException;
+import java.util.ServiceLoader;
+
+import com.google.common.annotations.VisibleForTesting;
 
 import org.apache.celeborn.common.CelebornConf;
+import org.apache.celeborn.common.util.Utils;
 
 public class DynamicConfigServiceFactory {
   private static volatile ConfigService _INSTANCE;
 
-  public static ConfigService getConfigService(CelebornConf celebornConf) throws IOException {
+  public static ConfigService getConfigService(CelebornConf celebornConf) {
     if (celebornConf.dynamicConfigStoreBackend().isEmpty()) {
       return null;
     }
@@ -33,15 +36,25 @@ public class DynamicConfigServiceFactory {
       synchronized (DynamicConfigServiceFactory.class) {
         if (_INSTANCE == null) {
           String configStoreBackend = celebornConf.dynamicConfigStoreBackend().get();
-          if ("FS".equals(configStoreBackend)) {
-            _INSTANCE = new FsConfigServiceImpl(celebornConf);
-          } else {
-            _INSTANCE = new DbConfigServiceImpl(celebornConf);
+          for (ConfigStore configStore : ServiceLoader.load(ConfigStore.class)) {
+            if (configStore.getName().equalsIgnoreCase(configStoreBackend)) {
+              configStoreBackend = configStore.getService();
+              break;
+            }
           }
+          _INSTANCE = Utils.instantiateDynamicConfigStoreBackend(configStoreBackend, celebornConf);
         }
       }
     }
 
     return _INSTANCE;
   }
+
+  @VisibleForTesting
+  public static void reset() {
+    if (_INSTANCE != null) {
+      _INSTANCE.shutdown();
+      _INSTANCE = null;
+    }
+  }
 }
