@@ -17,10 +17,12 @@
 
 package org.apache.celeborn.tests.spark
 
-import java.io.File
+import java.io.{File, IOException}
 import java.util.concurrent.atomic.AtomicBoolean
 
-import org.apache.spark.{SparkConf, SparkContextHelper, TaskContext}
+import org.apache.spark.{BarrierTaskContext, ShuffleDependency, SparkConf, SparkContextHelper, SparkException, TaskContext}
+import org.apache.spark.celeborn.ExceptionMakerHelper
+import org.apache.spark.rdd.RDD
 import org.apache.spark.shuffle.ShuffleHandle
 import org.apache.spark.shuffle.celeborn.{CelebornShuffleHandle, ShuffleManagerHook, SparkShuffleManager, SparkUtils, TestCelebornShuffleManager}
 import org.apache.spark.sql.SparkSession
@@ -102,7 +104,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
         .config(
           "spark.shuffle.manager",
@@ -144,7 +145,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "false")
         .getOrCreate()
 
@@ -177,7 +177,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
         .config(
           "spark.shuffle.manager",
@@ -209,7 +208,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
         .config(
           "spark.shuffle.manager",
@@ -250,7 +248,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
         .config(
           "spark.shuffle.manager",
@@ -282,7 +279,6 @@ class CelebornFetchFailureSuite extends AnyFunSuite
         .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
         .config("spark.sql.shuffle.partitions", 2)
         .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
-        .config("spark.celeborn.shuffle.enabled", "true")
         .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
         .getOrCreate()
 
@@ -297,4 +293,162 @@ class CelebornFetchFailureSuite extends AnyFunSuite
       sparkSession.stop()
     }
   }
+
+  test(s"celeborn spark integration test - resubmit an unordered barrier stage with throwsFetchFailure enabled") {
+    val sparkConf = new SparkConf().setAppName("rss-demo").setMaster("local[2]")
+    val sparkSession = SparkSession.builder()
+      .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
+      .config("spark.sql.shuffle.partitions", 2)
+      .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
+      .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
+      .config("spark.celeborn.client.push.buffer.max.size", 0)
+      .config(
+        "spark.shuffle.manager",
+        "org.apache.spark.shuffle.celeborn.TestCelebornShuffleManager")
+      .getOrCreate()
+
+    try {
+      val sc = sparkSession.sparkContext
+      val rdd1 = sc
+        .parallelize(0 until 10000, 2)
+        .map(v => (v, v))
+        .groupByKey()
+        .barrier()
+        .mapPartitions {
+          it =>
+            val context = BarrierTaskContext.get()
+            if (context.stageAttemptNumber() == 0 && context.partitionId() == 0) {
+              Thread.sleep(3000)
+              throw new RuntimeException("failed")
+            }
+            if (context.stageAttemptNumber() > 0) {
+              it.toBuffer.reverseIterator
+            } else {
+              it
+            }
+        }
+      val rdd2 = rdd1.map(v => (v._2, v._1)).groupByKey()
+      val result = rdd2.collect()
+      result.foreach {
+        elem =>
+          assert(elem._1.size == elem._2.size)
+      }
+    } finally {
+      sparkSession.stop()
+    }
+  }
+
+  test(s"celeborn spark integration test - fetch failure in child of an unordered barrier stage with throwsFetchFailure enabled") {
+    val sparkConf = new SparkConf().setAppName("rss-demo").setMaster("local[2]")
+    val sparkSession = SparkSession.builder()
+      .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
+      .config("spark.sql.shuffle.partitions", 2)
+      .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
+      .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
+      .config("spark.celeborn.client.push.buffer.max.size", 0)
+      .config(
+        "spark.shuffle.manager",
+        "org.apache.spark.shuffle.celeborn.TestCelebornShuffleManager")
+      .getOrCreate()
+
+    try {
+      val sc = sparkSession.sparkContext
+      val inputGroupedRdd = sc
+        .parallelize(0 until 10000, 2)
+        .map(v => (v, v))
+        .groupByKey()
+      val rdd1 = inputGroupedRdd
+        .barrier()
+        .mapPartitions(it => it)
+      val groupedRdd = rdd1.map(v => (v._2, v._1)).groupByKey()
+      val appShuffleId = findAppShuffleId(groupedRdd)
+      assert(findAppShuffleId(groupedRdd) != findAppShuffleId(inputGroupedRdd))
+      val rdd2 = groupedRdd.mapPartitions { iter =>
+        val context = TaskContext.get()
+        if (context.stageAttemptNumber() == 0 && context.partitionId() == 0) {
+          throw ExceptionMakerHelper.SHUFFLE_FETCH_FAILURE_EXCEPTION_MAKER.makeFetchFailureException(
+            appShuffleId,
+            -1,
+            context.partitionId(),
+            new IOException("forced"))
+        }
+        iter
+      }
+      val result = rdd2.collect()
+      result.foreach {
+        elem =>
+          assert(elem._1.size == elem._2.size)
+      }
+    } finally {
+      sparkSession.stop()
+    }
+  }
+
+  test(s"celeborn spark integration test - resubmit a failed barrier stage across jobs") {
+    val sparkConf = new SparkConf().setAppName("rss-demo").setMaster("local[2]")
+    val sparkSession = SparkSession.builder()
+      .config(updateSparkConf(sparkConf, ShuffleMode.HASH))
+      .config("spark.sql.shuffle.partitions", 2)
+      .config("spark.celeborn.shuffle.forceFallback.partition.enabled", false)
+      .config("spark.celeborn.client.spark.fetch.throwsFetchFailure", "true")
+      .config("spark.celeborn.client.push.buffer.max.size", 0)
+      .config("spark.stage.maxConsecutiveAttempts", "1")
+      .config("spark.stage.maxAttempts", "1")
+      .config(
+        "spark.shuffle.manager",
+        "org.apache.spark.shuffle.celeborn.TestCelebornShuffleManager")
+      .getOrCreate()
+
+    // trigger failure
+    CelebornFetchFailureSuite.triggerFailure.set(true)
+
+    try {
+      val sc = sparkSession.sparkContext
+      val rdd1 = sc
+        .parallelize(0 until 10000, 2)
+        .map(v => (v, v))
+        .groupByKey()
+        .barrier()
+        .mapPartitions {
+          it =>
+            val context = BarrierTaskContext.get()
+            if (context.partitionId() == 0 && CelebornFetchFailureSuite.triggerFailure.get()) {
+              Thread.sleep(3000)
+              throw new RuntimeException("failed")
+            }
+            if (CelebornFetchFailureSuite.triggerFailure.get()) {
+              it
+            } else {
+              it.toBuffer.reverseIterator
+            }
+        }
+      val rdd2 = rdd1.map(v => (v._2, v._1)).groupByKey()
+      assertThrows[SparkException] {
+        rdd2.collect()
+      }
+
+      // Now, allow it to succeed
+      CelebornFetchFailureSuite.triggerFailure.set(false)
+      val result = rdd2.collect()
+      result.foreach {
+        elem =>
+          assert(elem._1.size == elem._2.size)
+      }
+    } finally {
+      sparkSession.stop()
+    }
+  }
+
+  private def findAppShuffleId(rdd: RDD[_]): Int = {
+    val deps = rdd.dependencies
+    if (deps.size != 1 && !deps.head.isInstanceOf[ShuffleDependency[_, _, _]]) {
+      throw new IllegalArgumentException("Expected an RDD with shuffle dependency: " + rdd)
+    }
+
+    deps.head.asInstanceOf[ShuffleDependency[_, _, _]].shuffleId
+  }
+}
+
+object CelebornFetchFailureSuite {
+  private val triggerFailure = new AtomicBoolean(false)
 }
